==> generator-jhipster-primeng-2.2.0.tgz: package/README.md <==
# generator-jhipster-primeng
> Click :star:if you like the project. Pull Request are highly appreciated.

[![NPM version][npm-image]][npm-url] [![npm](https://img.shields.io/npm/dt/generator-jhipster-primeng.svg)]() ![Crates.io](https://img.shields.io/github/license/mashape/apistatus.svg)
> JHipster module, Generate PrimeNG application with 90+ components and their features 

<div align="center">
  <a href="http://jhipster.github.io">
    <img src="https://raw.githubusercontent.com/jhipster/jhipster.github.io/master/images/logo/logo-jhipster.png">
  </a>
  <a href="https://www.primefaces.org/primeng">
    <img width=120px src="https://pbs.twimg.com/profile_images/782907169414979584/i2fYktgo.jpg">
  </a>
</div>

# Introduction

This is a [JHipster](http://jhipster.github.io/) module, that is meant to be used in a JHipster application.

The minimum required version of JHipster is **>=5.7.0**

This module is used to generate components, using [PrimeNG](https://www.primefaces.org/primeng).

# Prerequisites

As this is a [JHipster](http://jhipster.github.io/) module, we expect you have JHipster and its related tools already installed:

- [Installing JHipster](https://jhipster.github.io/installation.html)

# Installation

## With YARN

First,we need to install yo as below,

```bash
yarn global add yo
```

To install this module:

```bash
yarn global add generator-jhipster-primeng
```

To update this module:

```bash
yarn global upgrade generator-jhipster-primeng
```

## With NPM

To install this module:

```bash
npm install -g generator-jhipster-primeng
```

To update this module:

```bash
npm update -g generator-jhipster-primeng
```
## Getting Started

1. Run JHipster-PrimeNG module using **yo jhipster-primeng** command
2. Select your favourite theme

<div align="center">
    <img src="https://raw.githubusercontent.com/sudheerj/generator-jhipster-primeng/master/images/theme-2.1.png" height="400" width="700">
</div>

3. Either select component group or individual components

 <div align="center">
     <img src="https://raw.githubusercontent.com/sudheerj/generator-jhipster-primeng/master/images/groups.png" height="400" width="700">
 </div>
 
 
 <div align="center">
     <img src="https://raw.githubusercontent.com/sudheerj/generator-jhipster-primeng/master/images/components-2.1.png" height="400" width="700">
 </div>
 
 4. Select your component and navigate to required features
 
 <div align="center">
     <img src="https://raw.githubusercontent.com/sudheerj/generator-jhipster-primeng/master/images/application.png" height="400" width="700">
 </div>

# What next?
Please check the road map list https://github.com/sudheerj/generator-jhipster-primeng/wiki/Roadmap. If you need a new feature please raise a github request for the discussion.

# Blog
http://sudheerjonna.com/blog/2017/10/09/jhipster-meets-primeng-or-primeng-meets-jhipster/

# Usage

In your JHipster project, launch `yo jhipster-primeng` and confirm.

[npm-image]: https://img.shields.io/npm/v/generator-jhipster-primeng.svg
[npm-url]: https://npmjs.org/package/generator-jhipster-primeng
[travis-image]: https://travis-ci.org/sudheerj/generator-jhipster-primeng.svg?branch=master
[travis-url]: https://travis-ci.org/sudheerj/generator-jhipster-primeng
[daviddm-image]: https://david-dm.org/sudheerj/generator-jhipster-primeng.svg?theme=shields.io
[daviddm-url]: https://david-dm.org/sudheerj/generator-jhipster-module
[coveralls-image]: https://coveralls.io/repos/sudheerj/generator-jhipster-primeng/badge.svg?branch=master&service=github
[coveralls-url]: https://coveralls.io/github/sudheerj/generator-jhipster-primeng?branch=master

==> generator-jhipster-primeng-2.3.0.tgz: package/README.md <==
# generator-jhipster-primeng
> Click :star:if you like the project. Pull Requests are highly appreciated.

[![NPM version][npm-image]][npm-url] [![npm](https://img.shields.io/npm/dt/generator-jhipster-primeng.svg)]() ![Crates.io](https://img.shields.io/github/license/mashape/apistatus.svg)
> JHipster module, Generate PrimeNG application with 90+ components and their features 

<div align="center">
  <a href="http://jhipster.github.io">
    <img src="https://raw.githubusercontent.com/jhipster/jhipster.github.io/master/images/logo/logo-jhipster.png">
  </a>
  <a href="https://www.primefaces.org/primeng">
    <img width=120px src="https://pbs.twimg.com/profile_images/782907169414979584/i2fYktgo.jpg">
  </a>
</div>

# Introduction

This is a [JHipster](http://jhipster.github.io/) module, that is meant to be used in a JHipster application.

The minimum required version of JHipster is **>=5.8.2**

This module is used to generate components, using [PrimeNG](https://www.primefaces.org/primeng).

# Prerequisites

As this is a [JHipster](http://jhipster.github.io/) module, we expect you have JHipster and its related tools already installed:

- [Installing JHipster](https://jhipster.github.io/installation.html)

# Installation

## With YARN

First,we need to install yo as below,

```bash
yarn global add yo
```

To install this module:

```bash
yarn global add generator-jhipster-primeng
```

To update this module:

```bash
yarn global upgrade generator-jhipster-primeng
```

## With NPM

To install this module:

```bash
npm install -g generator-jhipster-primeng
```

To update this module:

```bash
npm update -g generator-jhipster-primeng
```
## Getting Started

1. Run JHipster-PrimeNG module using **yo jhipster-primeng** command
2. Select your favourite theme

<div align="center">
    <img src="https://raw.githubusercontent.com/sudheerj/generator-jhipster-primeng/master/images/theme-2.1.png" height="400" width="700">
</div>

3. Either select component group or individual components

 <div align="center">
     <img src="https://raw.githubusercontent.com/sudheerj/generator-jhipster-primeng/master/images/groups-2.3.png" height="400" width="700">
 </div>
 
 
 <div align="center">
     <img src="https://raw.githubusercontent.com/sudheerj/generator-jhipster-primeng/master/images/components-2.1.png" height="400" width="700">
 </div>
 
 4. Select your component and navigate to required features
 
 <div align="center">
     <img src="https://raw.githubusercontent.com/sudheerj/generator-jhipster-primeng/master/images/application.png" height="400" width="700">
 </div>
 
 5. Run client and server side environments
 
    **Client: npm start**
    
    **Server: ./mvnw**
    
 6. Open application in the browser using http://localhost:9000    

# What next?
Please check the road map list https://github.com/sudheerj/generator-jhipster-primeng/wiki/Roadmap. If you need a new feature please raise a github request for the discussion.

# Blog
http://sudheerjonna.com/blog/2017/10/09/jhipster-meets-primeng-or-primeng-meets-jhipster/

# Usage

In your JHipster project, launch `yo jhipster-primeng` and confirm.

[npm-image]: https://img.shields.io/npm/v/generator-jhipster-primeng.svg
[npm-url]: https://npmjs.org/package/generator-jhipster-primeng
[travis-image]: https://travis-ci.org/sudheerj/generator-jhipster-primeng.svg?branch=master
[travis-url]: https://travis-ci.org/sudheerj/generator-jhipster-primeng
[daviddm-image]: https://david-dm.org/sudheerj/generator-jhipster-primeng.svg?theme=shields.io
[daviddm-url]: https://david-dm.org/sudheerj/generator-jhipster-module
[coveralls-image]: https://coveralls.io/repos/sudheerj/generator-jhipster-primeng/badge.svg?branch=master&service=github
[coveralls-url]: https://coveralls.io/github/sudheerj/generator-jhipster-primeng?branch=master
